if [ -x usr/bin/scrollkeeper-update ]; then
  usr/bin/scrollkeeper-update -p var/lib/scrollkeeper 1> /dev/null 2> /dev/null
fi

if [ -x usr/bin/update-mime-database ]; then
  usr/bin/update-mime-database usr/share/mime 1> /dev/null 2> /dev/null
fi

if [ -x usr/bin/update-desktop-database ]; then
  usr/bin/update-desktop-database 1> /dev/null 2> /dev/null
fi
( cd usr/lib/evolution/2.2 ; rm -rf libeutil.so.0 )
( cd usr/lib/evolution/2.2 ; ln -sf libeutil.so.0.0.0 libeutil.so.0 )
( cd usr/lib/evolution/2.2 ; rm -rf libeutil.so )
( cd usr/lib/evolution/2.2 ; ln -sf libeutil.so.0.0.0 libeutil.so )
( cd usr/lib/evolution/2.2 ; rm -rf libeconduit.so.0 )
( cd usr/lib/evolution/2.2 ; ln -sf libeconduit.so.0.0.0 libeconduit.so.0 )
( cd usr/lib/evolution/2.2 ; rm -rf libeconduit.so )
( cd usr/lib/evolution/2.2 ; ln -sf libeconduit.so.0.0.0 libeconduit.so )
( cd usr/lib/evolution/2.2 ; rm -rf libevolution-a11y.so.0 )
( cd usr/lib/evolution/2.2 ; ln -sf libevolution-a11y.so.0.0.0 libevolution-a11y.so.0 )
( cd usr/lib/evolution/2.2 ; rm -rf libevolution-a11y.so )
( cd usr/lib/evolution/2.2 ; ln -sf libevolution-a11y.so.0.0.0 libevolution-a11y.so )
( cd usr/lib/evolution/2.2 ; rm -rf libevolution-calendar-a11y.so.0 )
( cd usr/lib/evolution/2.2 ; ln -sf libevolution-calendar-a11y.so.0.0.0 libevolution-calendar-a11y.so.0 )
( cd usr/lib/evolution/2.2 ; rm -rf libevolution-calendar-a11y.so )
( cd usr/lib/evolution/2.2 ; ln -sf libevolution-calendar-a11y.so.0.0.0 libevolution-calendar-a11y.so )
( cd usr/lib/evolution/2.2 ; rm -rf libevolution-widgets-a11y.so.0 )
( cd usr/lib/evolution/2.2 ; ln -sf libevolution-widgets-a11y.so.0.0.0 libevolution-widgets-a11y.so.0 )
( cd usr/lib/evolution/2.2 ; rm -rf libevolution-widgets-a11y.so )
( cd usr/lib/evolution/2.2 ; ln -sf libevolution-widgets-a11y.so.0.0.0 libevolution-widgets-a11y.so )
( cd usr/lib/evolution/2.2 ; rm -rf libevolution-addressbook-a11y.so.0 )
( cd usr/lib/evolution/2.2 ; ln -sf libevolution-addressbook-a11y.so.0.0.0 libevolution-addressbook-a11y.so.0 )
( cd usr/lib/evolution/2.2 ; rm -rf libevolution-addressbook-a11y.so )
( cd usr/lib/evolution/2.2 ; ln -sf libevolution-addressbook-a11y.so.0.0.0 libevolution-addressbook-a11y.so )
( cd usr/lib/evolution/2.2 ; rm -rf libetimezonedialog.so.0 )
( cd usr/lib/evolution/2.2 ; ln -sf libetimezonedialog.so.0.0.0 libetimezonedialog.so.0 )
( cd usr/lib/evolution/2.2 ; rm -rf libetimezonedialog.so )
( cd usr/lib/evolution/2.2 ; ln -sf libetimezonedialog.so.0.0.0 libetimezonedialog.so )
( cd usr/lib/evolution/2.2 ; rm -rf libemiscwidgets.so.0 )
( cd usr/lib/evolution/2.2 ; ln -sf libemiscwidgets.so.0.0.0 libemiscwidgets.so.0 )
( cd usr/lib/evolution/2.2 ; rm -rf libemiscwidgets.so )
( cd usr/lib/evolution/2.2 ; ln -sf libemiscwidgets.so.0.0.0 libemiscwidgets.so )
( cd usr/lib/evolution/2.2 ; rm -rf libefilterbar.so.0 )
( cd usr/lib/evolution/2.2 ; ln -sf libefilterbar.so.0.0.0 libefilterbar.so.0 )
( cd usr/lib/evolution/2.2 ; rm -rf libefilterbar.so )
( cd usr/lib/evolution/2.2 ; ln -sf libefilterbar.so.0.0.0 libefilterbar.so )
( cd usr/lib/evolution/2.2 ; rm -rf libmenus.so.0 )
( cd usr/lib/evolution/2.2 ; ln -sf libmenus.so.0.0.0 libmenus.so.0 )
( cd usr/lib/evolution/2.2 ; rm -rf libmenus.so )
( cd usr/lib/evolution/2.2 ; ln -sf libmenus.so.0.0.0 libmenus.so )
( cd usr/lib/evolution/2.2 ; rm -rf libevolution-importer.so.0 )
( cd usr/lib/evolution/2.2 ; ln -sf libevolution-importer.so.0.0.0 libevolution-importer.so.0 )
( cd usr/lib/evolution/2.2 ; rm -rf libevolution-importer.so )
( cd usr/lib/evolution/2.2 ; ln -sf libevolution-importer.so.0.0.0 libevolution-importer.so )
( cd usr/lib/evolution/2.2 ; rm -rf libeshell.so.0 )
( cd usr/lib/evolution/2.2 ; ln -sf libeshell.so.0.0.0 libeshell.so.0 )
( cd usr/lib/evolution/2.2 ; rm -rf libeshell.so )
( cd usr/lib/evolution/2.2 ; ln -sf libeshell.so.0.0.0 libeshell.so )
( cd usr/lib/evolution/2.2 ; rm -rf libfilter.so.0 )
( cd usr/lib/evolution/2.2 ; ln -sf libfilter.so.0.0.0 libfilter.so.0 )
( cd usr/lib/evolution/2.2 ; rm -rf libfilter.so )
( cd usr/lib/evolution/2.2 ; ln -sf libfilter.so.0.0.0 libfilter.so )
( cd usr/lib/evolution/2.2 ; rm -rf libessmime.so.0 )
( cd usr/lib/evolution/2.2 ; ln -sf libessmime.so.0.0.0 libessmime.so.0 )
( cd usr/lib/evolution/2.2 ; rm -rf libessmime.so )
( cd usr/lib/evolution/2.2 ; ln -sf libessmime.so.0.0.0 libessmime.so )
( cd usr/lib/evolution/2.2 ; rm -rf libevolution-smime.so.0 )
( cd usr/lib/evolution/2.2 ; ln -sf libevolution-smime.so.0.0.0 libevolution-smime.so.0 )
( cd usr/lib/evolution/2.2 ; rm -rf libevolution-smime.so )
( cd usr/lib/evolution/2.2 ; ln -sf libevolution-smime.so.0.0.0 libevolution-smime.so )
( cd usr/lib/evolution/2.2 ; rm -rf libeabutil.so.0 )
( cd usr/lib/evolution/2.2 ; ln -sf libeabutil.so.0.0.0 libeabutil.so.0 )
( cd usr/lib/evolution/2.2 ; rm -rf libeabutil.so )
( cd usr/lib/evolution/2.2 ; ln -sf libeabutil.so.0.0.0 libeabutil.so )
( cd usr/lib/evolution/2.2 ; rm -rf libecontacteditor.so.0 )
( cd usr/lib/evolution/2.2 ; ln -sf libecontacteditor.so.0.0.0 libecontacteditor.so.0 )
( cd usr/lib/evolution/2.2 ; rm -rf libecontacteditor.so )
( cd usr/lib/evolution/2.2 ; ln -sf libecontacteditor.so.0.0.0 libecontacteditor.so )
( cd usr/lib/evolution/2.2 ; rm -rf libecontactlisteditor.so.0 )
( cd usr/lib/evolution/2.2 ; ln -sf libecontactlisteditor.so.0.0.0 libecontactlisteditor.so.0 )
( cd usr/lib/evolution/2.2 ; rm -rf libecontactlisteditor.so )
( cd usr/lib/evolution/2.2 ; ln -sf libecontactlisteditor.so.0.0.0 libecontactlisteditor.so )
( cd usr/lib/evolution/2.2 ; rm -rf libevolution-mail-importers.so.0 )
( cd usr/lib/evolution/2.2 ; ln -sf libevolution-mail-importers.so.0.0.0 libevolution-mail-importers.so.0 )
( cd usr/lib/evolution/2.2 ; rm -rf libevolution-mail-importers.so )
( cd usr/lib/evolution/2.2 ; ln -sf libevolution-mail-importers.so.0.0.0 libevolution-mail-importers.so )
