/*
 * This file was generated by orbit-idl-2 - DO NOT EDIT!
 */

#ifndef Evolution_H
#define Evolution_H 1
#include <glib.h>
#define ORBIT_IDL_SERIAL 20
#include <orbit/orbit-types.h>

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */


/** typedefs **/
#include <bonobo/Bonobo.h>
#if !defined(_GNOME_Evolution_Icon_defined)
#define _GNOME_Evolution_Icon_defined 1
typedef struct GNOME_Evolution_Icon_type GNOME_Evolution_Icon;
#if !defined(ORBIT_DECL_CORBA_sequence_CORBA_octet)
#define ORBIT_DECL_CORBA_sequence_CORBA_octet 1
#define ORBIT_IMPL_CORBA_sequence_CORBA_octet_0 'E'
#define ORBIT_IMPL_CORBA_sequence_CORBA_octet_1 'v'
#define ORBIT_IMPL_CORBA_sequence_CORBA_octet_2 'o'
#define ORBIT_IMPL_CORBA_sequence_CORBA_octet_3 'l'
#define ORBIT_IMPL_CORBA_sequence_CORBA_octet_4 'u'
#define ORBIT_IMPL_CORBA_sequence_CORBA_octet_5 't'
#define ORBIT_IMPL_CORBA_sequence_CORBA_octet_6 'i'
#define ORBIT_IMPL_CORBA_sequence_CORBA_octet_7 'o'
#define ORBIT_IMPL_CORBA_sequence_CORBA_octet_8 'n'
#if !defined(_CORBA_sequence_CORBA_octet_defined)
#define _CORBA_sequence_CORBA_octet_defined 1
typedef struct { CORBA_unsigned_long _maximum, _length; CORBA_octet* _buffer; CORBA_boolean _release; } CORBA_sequence_CORBA_octet;
#endif
#if !defined(TC_IMPL_TC_CORBA_sequence_CORBA_octet_0)
#define TC_IMPL_TC_CORBA_sequence_CORBA_octet_0 'E'
#define TC_IMPL_TC_CORBA_sequence_CORBA_octet_1 'v'
#define TC_IMPL_TC_CORBA_sequence_CORBA_octet_2 'o'
#define TC_IMPL_TC_CORBA_sequence_CORBA_octet_3 'l'
#define TC_IMPL_TC_CORBA_sequence_CORBA_octet_4 'u'
#define TC_IMPL_TC_CORBA_sequence_CORBA_octet_5 't'
#define TC_IMPL_TC_CORBA_sequence_CORBA_octet_6 'i'
#define TC_IMPL_TC_CORBA_sequence_CORBA_octet_7 'o'
#define TC_IMPL_TC_CORBA_sequence_CORBA_octet_8 'n'
#ifdef ORBIT_IDL_C_IMODULE_Evolution
static
#else
extern
#endif
struct CORBA_TypeCode_struct TC_CORBA_sequence_CORBA_octet_struct;
#define TC_CORBA_sequence_CORBA_octet ((CORBA_TypeCode)&TC_CORBA_sequence_CORBA_octet_struct)
#endif
#define CORBA_sequence_CORBA_octet__alloc() ((CORBA_sequence_CORBA_octet *)ORBit_small_alloc (TC_CORBA_sequence_CORBA_octet))
#define CORBA_sequence_CORBA_octet__freekids(m,d) ORBit_small_freekids (TC_CORBA_sequence_CORBA_octet,(m),(d))
#define CORBA_sequence_CORBA_octet_allocbuf(l) ((CORBA_octet*)ORBit_small_allocbuf (TC_CORBA_sequence_CORBA_octet, (l)))
#define CORBA_sequence_CORBA_octet_allocbuf(l) ((CORBA_octet*)ORBit_small_allocbuf (TC_CORBA_sequence_CORBA_octet, (l)))
#endif
struct GNOME_Evolution_Icon_type {
CORBA_short width;
CORBA_short height;
CORBA_boolean hasAlpha;
CORBA_sequence_CORBA_octet rgbaData;
};

#if !defined(TC_IMPL_TC_GNOME_Evolution_Icon_0)
#define TC_IMPL_TC_GNOME_Evolution_Icon_0 'E'
#define TC_IMPL_TC_GNOME_Evolution_Icon_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Icon_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Icon_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Icon_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Icon_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Icon_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Icon_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Icon_8 'n'
#ifdef ORBIT_IDL_C_IMODULE_Evolution
static
#else
extern
#endif
struct CORBA_TypeCode_struct TC_GNOME_Evolution_Icon_struct;
#define TC_GNOME_Evolution_Icon ((CORBA_TypeCode)&TC_GNOME_Evolution_Icon_struct)
#endif
#define GNOME_Evolution_Icon__alloc() ((GNOME_Evolution_Icon *)ORBit_small_alloc (TC_GNOME_Evolution_Icon))
#define GNOME_Evolution_Icon__freekids(m,d) ORBit_small_freekids (TC_GNOME_Evolution_Icon,(m),(d))
#endif
#if !defined(ORBIT_DECL_CORBA_sequence_GNOME_Evolution_Icon)
#define ORBIT_DECL_CORBA_sequence_GNOME_Evolution_Icon 1
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Icon_0 'E'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Icon_1 'v'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Icon_2 'o'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Icon_3 'l'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Icon_4 'u'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Icon_5 't'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Icon_6 'i'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Icon_7 'o'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Icon_8 'n'
#if !defined(_CORBA_sequence_GNOME_Evolution_Icon_defined)
#define _CORBA_sequence_GNOME_Evolution_Icon_defined 1
typedef struct { CORBA_unsigned_long _maximum, _length; GNOME_Evolution_Icon* _buffer; CORBA_boolean _release; } CORBA_sequence_GNOME_Evolution_Icon;
#endif
#if !defined(TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Icon_0)
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Icon_0 'E'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Icon_1 'v'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Icon_2 'o'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Icon_3 'l'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Icon_4 'u'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Icon_5 't'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Icon_6 'i'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Icon_7 'o'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Icon_8 'n'
#ifdef ORBIT_IDL_C_IMODULE_Evolution
static
#else
extern
#endif
struct CORBA_TypeCode_struct TC_CORBA_sequence_GNOME_Evolution_Icon_struct;
#define TC_CORBA_sequence_GNOME_Evolution_Icon ((CORBA_TypeCode)&TC_CORBA_sequence_GNOME_Evolution_Icon_struct)
#endif
#define CORBA_sequence_GNOME_Evolution_Icon__alloc() ((CORBA_sequence_GNOME_Evolution_Icon *)ORBit_small_alloc (TC_CORBA_sequence_GNOME_Evolution_Icon))
#define CORBA_sequence_GNOME_Evolution_Icon__freekids(m,d) ORBit_small_freekids (TC_CORBA_sequence_GNOME_Evolution_Icon,(m),(d))
#define CORBA_sequence_GNOME_Evolution_Icon_allocbuf(l) ((GNOME_Evolution_Icon*)ORBit_small_allocbuf (TC_CORBA_sequence_GNOME_Evolution_Icon, (l)))
#define CORBA_sequence_GNOME_Evolution_Icon_allocbuf(l) ((GNOME_Evolution_Icon*)ORBit_small_allocbuf (TC_CORBA_sequence_GNOME_Evolution_Icon, (l)))
#endif
#if !defined(_GNOME_Evolution_AnimatedIcon_defined)
#define _GNOME_Evolution_AnimatedIcon_defined 1
typedef CORBA_sequence_GNOME_Evolution_Icon GNOME_Evolution_AnimatedIcon;
#define GNOME_Evolution_AnimatedIcon_marshal(x,y,z) CORBA_sequence_GNOME_Evolution_Icon_marshal((x),(y),(z))
#define GNOME_Evolution_AnimatedIcon_demarshal(x,y,z,i) CORBA_sequence_GNOME_Evolution_Icon_demarshal((x),(y),(z),(i))
#if !defined(TC_IMPL_TC_GNOME_Evolution_AnimatedIcon_0)
#define TC_IMPL_TC_GNOME_Evolution_AnimatedIcon_0 'E'
#define TC_IMPL_TC_GNOME_Evolution_AnimatedIcon_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_AnimatedIcon_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_AnimatedIcon_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_AnimatedIcon_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_AnimatedIcon_5 't'
#define TC_IMPL_TC_GNOME_Evolution_AnimatedIcon_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_AnimatedIcon_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_AnimatedIcon_8 'n'
#ifdef ORBIT_IDL_C_IMODULE_Evolution
static
#else
extern
#endif
struct CORBA_TypeCode_struct TC_GNOME_Evolution_AnimatedIcon_struct;
#define TC_GNOME_Evolution_AnimatedIcon ((CORBA_TypeCode)&TC_GNOME_Evolution_AnimatedIcon_struct)
#endif
#define GNOME_Evolution_AnimatedIcon__alloc() ((GNOME_Evolution_AnimatedIcon *)ORBit_small_alloc (TC_CORBA_sequence_GNOME_Evolution_Icon))
#define GNOME_Evolution_AnimatedIcon__freekids(m,d) ORBit_small_freekids (TC_CORBA_sequence_GNOME_Evolution_Icon,(m),(d))
#define GNOME_Evolution_AnimatedIcon_allocbuf(l) ((GNOME_Evolution_Icon*)ORBit_small_allocbuf (TC_CORBA_sequence_GNOME_Evolution_Icon, (l)))
#endif
#if !defined(_GNOME_Evolution_CreatableItem_defined)
#define _GNOME_Evolution_CreatableItem_defined 1
typedef enum {
  GNOME_Evolution_CREATABLE_OBJECT,
  GNOME_Evolution_CREATABLE_FOLDER
} GNOME_Evolution_CreatableItem;
#if !defined(TC_IMPL_TC_GNOME_Evolution_CreatableItem_0)
#define TC_IMPL_TC_GNOME_Evolution_CreatableItem_0 'E'
#define TC_IMPL_TC_GNOME_Evolution_CreatableItem_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_CreatableItem_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_CreatableItem_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_CreatableItem_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_CreatableItem_5 't'
#define TC_IMPL_TC_GNOME_Evolution_CreatableItem_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_CreatableItem_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_CreatableItem_8 'n'
#ifdef ORBIT_IDL_C_IMODULE_Evolution
static
#else
extern
#endif
struct CORBA_TypeCode_struct TC_GNOME_Evolution_CreatableItem_struct;
#define TC_GNOME_Evolution_CreatableItem ((CORBA_TypeCode)&TC_GNOME_Evolution_CreatableItem_struct)
#endif
#endif
#if !defined(_GNOME_Evolution_CreatableItemType_defined)
#define _GNOME_Evolution_CreatableItemType_defined 1
typedef struct GNOME_Evolution_CreatableItemType_type GNOME_Evolution_CreatableItemType;
struct GNOME_Evolution_CreatableItemType_type {
CORBA_string id;
CORBA_string description;
CORBA_string menuDescription;
CORBA_string tooltip;
CORBA_char menuShortcut;
CORBA_string iconName;
GNOME_Evolution_CreatableItem type;
};

#if !defined(TC_IMPL_TC_GNOME_Evolution_CreatableItemType_0)
#define TC_IMPL_TC_GNOME_Evolution_CreatableItemType_0 'E'
#define TC_IMPL_TC_GNOME_Evolution_CreatableItemType_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_CreatableItemType_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_CreatableItemType_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_CreatableItemType_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_CreatableItemType_5 't'
#define TC_IMPL_TC_GNOME_Evolution_CreatableItemType_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_CreatableItemType_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_CreatableItemType_8 'n'
#ifdef ORBIT_IDL_C_IMODULE_Evolution
static
#else
extern
#endif
struct CORBA_TypeCode_struct TC_GNOME_Evolution_CreatableItemType_struct;
#define TC_GNOME_Evolution_CreatableItemType ((CORBA_TypeCode)&TC_GNOME_Evolution_CreatableItemType_struct)
#endif
#define GNOME_Evolution_CreatableItemType__alloc() ((GNOME_Evolution_CreatableItemType *)ORBit_small_alloc (TC_GNOME_Evolution_CreatableItemType))
#define GNOME_Evolution_CreatableItemType__freekids(m,d) ORBit_small_freekids (TC_GNOME_Evolution_CreatableItemType,(m),(d))
#endif
#if !defined(ORBIT_DECL_CORBA_sequence_GNOME_Evolution_CreatableItemType)
#define ORBIT_DECL_CORBA_sequence_GNOME_Evolution_CreatableItemType 1
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_CreatableItemType_0 'E'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_CreatableItemType_1 'v'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_CreatableItemType_2 'o'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_CreatableItemType_3 'l'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_CreatableItemType_4 'u'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_CreatableItemType_5 't'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_CreatableItemType_6 'i'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_CreatableItemType_7 'o'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_CreatableItemType_8 'n'
#if !defined(_CORBA_sequence_GNOME_Evolution_CreatableItemType_defined)
#define _CORBA_sequence_GNOME_Evolution_CreatableItemType_defined 1
typedef struct { CORBA_unsigned_long _maximum, _length; GNOME_Evolution_CreatableItemType* _buffer; CORBA_boolean _release; } CORBA_sequence_GNOME_Evolution_CreatableItemType;
#endif
#if !defined(TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_CreatableItemType_0)
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_CreatableItemType_0 'E'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_CreatableItemType_1 'v'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_CreatableItemType_2 'o'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_CreatableItemType_3 'l'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_CreatableItemType_4 'u'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_CreatableItemType_5 't'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_CreatableItemType_6 'i'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_CreatableItemType_7 'o'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_CreatableItemType_8 'n'
#ifdef ORBIT_IDL_C_IMODULE_Evolution
static
#else
extern
#endif
struct CORBA_TypeCode_struct TC_CORBA_sequence_GNOME_Evolution_CreatableItemType_struct;
#define TC_CORBA_sequence_GNOME_Evolution_CreatableItemType ((CORBA_TypeCode)&TC_CORBA_sequence_GNOME_Evolution_CreatableItemType_struct)
#endif
#define CORBA_sequence_GNOME_Evolution_CreatableItemType__alloc() ((CORBA_sequence_GNOME_Evolution_CreatableItemType *)ORBit_small_alloc (TC_CORBA_sequence_GNOME_Evolution_CreatableItemType))
#define CORBA_sequence_GNOME_Evolution_CreatableItemType__freekids(m,d) ORBit_small_freekids (TC_CORBA_sequence_GNOME_Evolution_CreatableItemType,(m),(d))
#define CORBA_sequence_GNOME_Evolution_CreatableItemType_allocbuf(l) ((GNOME_Evolution_CreatableItemType*)ORBit_small_allocbuf (TC_CORBA_sequence_GNOME_Evolution_CreatableItemType, (l)))
#define CORBA_sequence_GNOME_Evolution_CreatableItemType_allocbuf(l) ((GNOME_Evolution_CreatableItemType*)ORBit_small_allocbuf (TC_CORBA_sequence_GNOME_Evolution_CreatableItemType, (l)))
#endif
#if !defined(_GNOME_Evolution_CreatableItemTypeList_defined)
#define _GNOME_Evolution_CreatableItemTypeList_defined 1
typedef CORBA_sequence_GNOME_Evolution_CreatableItemType GNOME_Evolution_CreatableItemTypeList;
#define GNOME_Evolution_CreatableItemTypeList_marshal(x,y,z) CORBA_sequence_GNOME_Evolution_CreatableItemType_marshal((x),(y),(z))
#define GNOME_Evolution_CreatableItemTypeList_demarshal(x,y,z,i) CORBA_sequence_GNOME_Evolution_CreatableItemType_demarshal((x),(y),(z),(i))
#if !defined(TC_IMPL_TC_GNOME_Evolution_CreatableItemTypeList_0)
#define TC_IMPL_TC_GNOME_Evolution_CreatableItemTypeList_0 'E'
#define TC_IMPL_TC_GNOME_Evolution_CreatableItemTypeList_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_CreatableItemTypeList_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_CreatableItemTypeList_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_CreatableItemTypeList_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_CreatableItemTypeList_5 't'
#define TC_IMPL_TC_GNOME_Evolution_CreatableItemTypeList_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_CreatableItemTypeList_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_CreatableItemTypeList_8 'n'
#ifdef ORBIT_IDL_C_IMODULE_Evolution
static
#else
extern
#endif
struct CORBA_TypeCode_struct TC_GNOME_Evolution_CreatableItemTypeList_struct;
#define TC_GNOME_Evolution_CreatableItemTypeList ((CORBA_TypeCode)&TC_GNOME_Evolution_CreatableItemTypeList_struct)
#endif
#define GNOME_Evolution_CreatableItemTypeList__alloc() ((GNOME_Evolution_CreatableItemTypeList *)ORBit_small_alloc (TC_CORBA_sequence_GNOME_Evolution_CreatableItemType))
#define GNOME_Evolution_CreatableItemTypeList__freekids(m,d) ORBit_small_freekids (TC_CORBA_sequence_GNOME_Evolution_CreatableItemType,(m),(d))
#define GNOME_Evolution_CreatableItemTypeList_allocbuf(l) ((GNOME_Evolution_CreatableItemType*)ORBit_small_allocbuf (TC_CORBA_sequence_GNOME_Evolution_CreatableItemType, (l)))
#endif
#if !defined(ORBIT_DECL_GNOME_Evolution_Component) && !defined(_GNOME_Evolution_Component_defined)
#define ORBIT_DECL_GNOME_Evolution_Component 1
#define _GNOME_Evolution_Component_defined 1
#define GNOME_Evolution_Component__freekids CORBA_Object__freekids
typedef CORBA_Object GNOME_Evolution_Component;
extern CORBA_unsigned_long GNOME_Evolution_Component__classid;
#if !defined(TC_IMPL_TC_GNOME_Evolution_Component_0)
#define TC_IMPL_TC_GNOME_Evolution_Component_0 'E'
#define TC_IMPL_TC_GNOME_Evolution_Component_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Component_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Component_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Component_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Component_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Component_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Component_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Component_8 'n'
#ifdef ORBIT_IDL_C_IMODULE_Evolution
static
#else
extern
#endif
struct CORBA_TypeCode_struct TC_GNOME_Evolution_Component_struct;
#define TC_GNOME_Evolution_Component ((CORBA_TypeCode)&TC_GNOME_Evolution_Component_struct)
#endif
#endif
#undef ex_GNOME_Evolution_Component_Failed
#define ex_GNOME_Evolution_Component_Failed "IDL:GNOME/Evolution/Component/Failed:1.0"
#if !defined(_GNOME_Evolution_Component_Failed_defined)
#define _GNOME_Evolution_Component_Failed_defined 1
typedef struct GNOME_Evolution_Component_Failed_type GNOME_Evolution_Component_Failed;
struct GNOME_Evolution_Component_Failed_type {
int dummy;
};

#if !defined(TC_IMPL_TC_GNOME_Evolution_Component_Failed_0)
#define TC_IMPL_TC_GNOME_Evolution_Component_Failed_0 'E'
#define TC_IMPL_TC_GNOME_Evolution_Component_Failed_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Component_Failed_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Component_Failed_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Component_Failed_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Component_Failed_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Component_Failed_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Component_Failed_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Component_Failed_8 'n'
#ifdef ORBIT_IDL_C_IMODULE_Evolution
static
#else
extern
#endif
struct CORBA_TypeCode_struct TC_GNOME_Evolution_Component_Failed_struct;
#define TC_GNOME_Evolution_Component_Failed ((CORBA_TypeCode)&TC_GNOME_Evolution_Component_Failed_struct)
#endif
#define GNOME_Evolution_Component_Failed__alloc() ((GNOME_Evolution_Component_Failed *)ORBit_small_alloc (TC_GNOME_Evolution_Component_Failed))
#define GNOME_Evolution_Component_Failed__freekids(m,d) ORBit_small_freekids (TC_GNOME_Evolution_Component_Failed,(m),(d))
#endif
#undef ex_GNOME_Evolution_Component_UnknownType
#define ex_GNOME_Evolution_Component_UnknownType "IDL:GNOME/Evolution/Component/UnknownType:1.0"
#if !defined(_GNOME_Evolution_Component_UnknownType_defined)
#define _GNOME_Evolution_Component_UnknownType_defined 1
typedef struct GNOME_Evolution_Component_UnknownType_type GNOME_Evolution_Component_UnknownType;
struct GNOME_Evolution_Component_UnknownType_type {
int dummy;
};

#if !defined(TC_IMPL_TC_GNOME_Evolution_Component_UnknownType_0)
#define TC_IMPL_TC_GNOME_Evolution_Component_UnknownType_0 'E'
#define TC_IMPL_TC_GNOME_Evolution_Component_UnknownType_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Component_UnknownType_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Component_UnknownType_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Component_UnknownType_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Component_UnknownType_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Component_UnknownType_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Component_UnknownType_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Component_UnknownType_8 'n'
#ifdef ORBIT_IDL_C_IMODULE_Evolution
static
#else
extern
#endif
struct CORBA_TypeCode_struct TC_GNOME_Evolution_Component_UnknownType_struct;
#define TC_GNOME_Evolution_Component_UnknownType ((CORBA_TypeCode)&TC_GNOME_Evolution_Component_UnknownType_struct)
#endif
#define GNOME_Evolution_Component_UnknownType__alloc() ((GNOME_Evolution_Component_UnknownType *)ORBit_small_alloc (TC_GNOME_Evolution_Component_UnknownType))
#define GNOME_Evolution_Component_UnknownType__freekids(m,d) ORBit_small_freekids (TC_GNOME_Evolution_Component_UnknownType,(m),(d))
#endif
#undef ex_GNOME_Evolution_Component_UnsupportedVersion
#define ex_GNOME_Evolution_Component_UnsupportedVersion "IDL:GNOME/Evolution/Component/UnsupportedVersion:1.0"
#if !defined(_GNOME_Evolution_Component_UnsupportedVersion_defined)
#define _GNOME_Evolution_Component_UnsupportedVersion_defined 1
typedef struct GNOME_Evolution_Component_UnsupportedVersion_type GNOME_Evolution_Component_UnsupportedVersion;
struct GNOME_Evolution_Component_UnsupportedVersion_type {
int dummy;
};

#if !defined(TC_IMPL_TC_GNOME_Evolution_Component_UnsupportedVersion_0)
#define TC_IMPL_TC_GNOME_Evolution_Component_UnsupportedVersion_0 'E'
#define TC_IMPL_TC_GNOME_Evolution_Component_UnsupportedVersion_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Component_UnsupportedVersion_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Component_UnsupportedVersion_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Component_UnsupportedVersion_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Component_UnsupportedVersion_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Component_UnsupportedVersion_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Component_UnsupportedVersion_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Component_UnsupportedVersion_8 'n'
#ifdef ORBIT_IDL_C_IMODULE_Evolution
static
#else
extern
#endif
struct CORBA_TypeCode_struct TC_GNOME_Evolution_Component_UnsupportedVersion_struct;
#define TC_GNOME_Evolution_Component_UnsupportedVersion ((CORBA_TypeCode)&TC_GNOME_Evolution_Component_UnsupportedVersion_struct)
#endif
#define GNOME_Evolution_Component_UnsupportedVersion__alloc() ((GNOME_Evolution_Component_UnsupportedVersion *)ORBit_small_alloc (TC_GNOME_Evolution_Component_UnsupportedVersion))
#define GNOME_Evolution_Component_UnsupportedVersion__freekids(m,d) ORBit_small_freekids (TC_GNOME_Evolution_Component_UnsupportedVersion,(m),(d))
#endif
#undef ex_GNOME_Evolution_Component_UpgradeFailed
#define ex_GNOME_Evolution_Component_UpgradeFailed "IDL:GNOME/Evolution/Component/UpgradeFailed:1.0"
#if !defined(_GNOME_Evolution_Component_UpgradeFailed_defined)
#define _GNOME_Evolution_Component_UpgradeFailed_defined 1
typedef struct GNOME_Evolution_Component_UpgradeFailed_type GNOME_Evolution_Component_UpgradeFailed;
struct GNOME_Evolution_Component_UpgradeFailed_type {
CORBA_string what;
CORBA_string why;
};

#if !defined(TC_IMPL_TC_GNOME_Evolution_Component_UpgradeFailed_0)
#define TC_IMPL_TC_GNOME_Evolution_Component_UpgradeFailed_0 'E'
#define TC_IMPL_TC_GNOME_Evolution_Component_UpgradeFailed_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Component_UpgradeFailed_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Component_UpgradeFailed_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Component_UpgradeFailed_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Component_UpgradeFailed_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Component_UpgradeFailed_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Component_UpgradeFailed_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Component_UpgradeFailed_8 'n'
#ifdef ORBIT_IDL_C_IMODULE_Evolution
static
#else
extern
#endif
struct CORBA_TypeCode_struct TC_GNOME_Evolution_Component_UpgradeFailed_struct;
#define TC_GNOME_Evolution_Component_UpgradeFailed ((CORBA_TypeCode)&TC_GNOME_Evolution_Component_UpgradeFailed_struct)
#endif
#define GNOME_Evolution_Component_UpgradeFailed__alloc() ((GNOME_Evolution_Component_UpgradeFailed *)ORBit_small_alloc (TC_GNOME_Evolution_Component_UpgradeFailed))
#define GNOME_Evolution_Component_UpgradeFailed__freekids(m,d) ORBit_small_freekids (TC_GNOME_Evolution_Component_UpgradeFailed,(m),(d))
#endif
#if !defined(ORBIT_DECL_GNOME_Evolution_ConfigControl) && !defined(_GNOME_Evolution_ConfigControl_defined)
#define ORBIT_DECL_GNOME_Evolution_ConfigControl 1
#define _GNOME_Evolution_ConfigControl_defined 1
#define GNOME_Evolution_ConfigControl__freekids CORBA_Object__freekids
typedef CORBA_Object GNOME_Evolution_ConfigControl;
extern CORBA_unsigned_long GNOME_Evolution_ConfigControl__classid;
#if !defined(TC_IMPL_TC_GNOME_Evolution_ConfigControl_0)
#define TC_IMPL_TC_GNOME_Evolution_ConfigControl_0 'E'
#define TC_IMPL_TC_GNOME_Evolution_ConfigControl_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_ConfigControl_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_ConfigControl_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_ConfigControl_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_ConfigControl_5 't'
#define TC_IMPL_TC_GNOME_Evolution_ConfigControl_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_ConfigControl_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_ConfigControl_8 'n'
#ifdef ORBIT_IDL_C_IMODULE_Evolution
static
#else
extern
#endif
struct CORBA_TypeCode_struct TC_GNOME_Evolution_ConfigControl_struct;
#define TC_GNOME_Evolution_ConfigControl ((CORBA_TypeCode)&TC_GNOME_Evolution_ConfigControl_struct)
#endif
#endif
#if !defined(_GNOME_Evolution_Connection_defined)
#define _GNOME_Evolution_Connection_defined 1
typedef struct GNOME_Evolution_Connection_type GNOME_Evolution_Connection;
struct GNOME_Evolution_Connection_type {
CORBA_string hostName;
CORBA_string type;
};

#if !defined(TC_IMPL_TC_GNOME_Evolution_Connection_0)
#define TC_IMPL_TC_GNOME_Evolution_Connection_0 'E'
#define TC_IMPL_TC_GNOME_Evolution_Connection_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Connection_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Connection_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Connection_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Connection_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Connection_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Connection_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Connection_8 'n'
#ifdef ORBIT_IDL_C_IMODULE_Evolution
static
#else
extern
#endif
struct CORBA_TypeCode_struct TC_GNOME_Evolution_Connection_struct;
#define TC_GNOME_Evolution_Connection ((CORBA_TypeCode)&TC_GNOME_Evolution_Connection_struct)
#endif
#define GNOME_Evolution_Connection__alloc() ((GNOME_Evolution_Connection *)ORBit_small_alloc (TC_GNOME_Evolution_Connection))
#define GNOME_Evolution_Connection__freekids(m,d) ORBit_small_freekids (TC_GNOME_Evolution_Connection,(m),(d))
#endif
#if !defined(ORBIT_DECL_CORBA_sequence_GNOME_Evolution_Connection)
#define ORBIT_DECL_CORBA_sequence_GNOME_Evolution_Connection 1
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Connection_0 'E'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Connection_1 'v'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Connection_2 'o'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Connection_3 'l'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Connection_4 'u'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Connection_5 't'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Connection_6 'i'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Connection_7 'o'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Connection_8 'n'
#if !defined(_CORBA_sequence_GNOME_Evolution_Connection_defined)
#define _CORBA_sequence_GNOME_Evolution_Connection_defined 1
typedef struct { CORBA_unsigned_long _maximum, _length; GNOME_Evolution_Connection* _buffer; CORBA_boolean _release; } CORBA_sequence_GNOME_Evolution_Connection;
#endif
#if !defined(TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Connection_0)
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Connection_0 'E'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Connection_1 'v'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Connection_2 'o'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Connection_3 'l'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Connection_4 'u'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Connection_5 't'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Connection_6 'i'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Connection_7 'o'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Connection_8 'n'
#ifdef ORBIT_IDL_C_IMODULE_Evolution
static
#else
extern
#endif
struct CORBA_TypeCode_struct TC_CORBA_sequence_GNOME_Evolution_Connection_struct;
#define TC_CORBA_sequence_GNOME_Evolution_Connection ((CORBA_TypeCode)&TC_CORBA_sequence_GNOME_Evolution_Connection_struct)
#endif
#define CORBA_sequence_GNOME_Evolution_Connection__alloc() ((CORBA_sequence_GNOME_Evolution_Connection *)ORBit_small_alloc (TC_CORBA_sequence_GNOME_Evolution_Connection))
#define CORBA_sequence_GNOME_Evolution_Connection__freekids(m,d) ORBit_small_freekids (TC_CORBA_sequence_GNOME_Evolution_Connection,(m),(d))
#define CORBA_sequence_GNOME_Evolution_Connection_allocbuf(l) ((GNOME_Evolution_Connection*)ORBit_small_allocbuf (TC_CORBA_sequence_GNOME_Evolution_Connection, (l)))
#define CORBA_sequence_GNOME_Evolution_Connection_allocbuf(l) ((GNOME_Evolution_Connection*)ORBit_small_allocbuf (TC_CORBA_sequence_GNOME_Evolution_Connection, (l)))
#endif
#if !defined(_GNOME_Evolution_ConnectionList_defined)
#define _GNOME_Evolution_ConnectionList_defined 1
typedef CORBA_sequence_GNOME_Evolution_Connection GNOME_Evolution_ConnectionList;
#define GNOME_Evolution_ConnectionList_marshal(x,y,z) CORBA_sequence_GNOME_Evolution_Connection_marshal((x),(y),(z))
#define GNOME_Evolution_ConnectionList_demarshal(x,y,z,i) CORBA_sequence_GNOME_Evolution_Connection_demarshal((x),(y),(z),(i))
#if !defined(TC_IMPL_TC_GNOME_Evolution_ConnectionList_0)
#define TC_IMPL_TC_GNOME_Evolution_ConnectionList_0 'E'
#define TC_IMPL_TC_GNOME_Evolution_ConnectionList_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_ConnectionList_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_ConnectionList_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_ConnectionList_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_ConnectionList_5 't'
#define TC_IMPL_TC_GNOME_Evolution_ConnectionList_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_ConnectionList_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_ConnectionList_8 'n'
#ifdef ORBIT_IDL_C_IMODULE_Evolution
static
#else
extern
#endif
struct CORBA_TypeCode_struct TC_GNOME_Evolution_ConnectionList_struct;
#define TC_GNOME_Evolution_ConnectionList ((CORBA_TypeCode)&TC_GNOME_Evolution_ConnectionList_struct)
#endif
#define GNOME_Evolution_ConnectionList__alloc() ((GNOME_Evolution_ConnectionList *)ORBit_small_alloc (TC_CORBA_sequence_GNOME_Evolution_Connection))
#define GNOME_Evolution_ConnectionList__freekids(m,d) ORBit_small_freekids (TC_CORBA_sequence_GNOME_Evolution_Connection,(m),(d))
#define GNOME_Evolution_ConnectionList_allocbuf(l) ((GNOME_Evolution_Connection*)ORBit_small_allocbuf (TC_CORBA_sequence_GNOME_Evolution_Connection, (l)))
#endif
#if !defined(ORBIT_DECL_GNOME_Evolution_OfflineProgressListener) && !defined(_GNOME_Evolution_OfflineProgressListener_defined)
#define ORBIT_DECL_GNOME_Evolution_OfflineProgressListener 1
#define _GNOME_Evolution_OfflineProgressListener_defined 1
#define GNOME_Evolution_OfflineProgressListener__freekids CORBA_Object__freekids
typedef CORBA_Object GNOME_Evolution_OfflineProgressListener;
extern CORBA_unsigned_long GNOME_Evolution_OfflineProgressListener__classid;
#if !defined(TC_IMPL_TC_GNOME_Evolution_OfflineProgressListener_0)
#define TC_IMPL_TC_GNOME_Evolution_OfflineProgressListener_0 'E'
#define TC_IMPL_TC_GNOME_Evolution_OfflineProgressListener_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_OfflineProgressListener_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_OfflineProgressListener_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_OfflineProgressListener_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_OfflineProgressListener_5 't'
#define TC_IMPL_TC_GNOME_Evolution_OfflineProgressListener_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_OfflineProgressListener_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_OfflineProgressListener_8 'n'
#ifdef ORBIT_IDL_C_IMODULE_Evolution
static
#else
extern
#endif
struct CORBA_TypeCode_struct TC_GNOME_Evolution_OfflineProgressListener_struct;
#define TC_GNOME_Evolution_OfflineProgressListener ((CORBA_TypeCode)&TC_GNOME_Evolution_OfflineProgressListener_struct)
#endif
#endif
#if !defined(ORBIT_DECL_GNOME_Evolution_Offline) && !defined(_GNOME_Evolution_Offline_defined)
#define ORBIT_DECL_GNOME_Evolution_Offline 1
#define _GNOME_Evolution_Offline_defined 1
#define GNOME_Evolution_Offline__freekids CORBA_Object__freekids
typedef CORBA_Object GNOME_Evolution_Offline;
extern CORBA_unsigned_long GNOME_Evolution_Offline__classid;
#if !defined(TC_IMPL_TC_GNOME_Evolution_Offline_0)
#define TC_IMPL_TC_GNOME_Evolution_Offline_0 'E'
#define TC_IMPL_TC_GNOME_Evolution_Offline_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Offline_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Offline_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Offline_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Offline_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Offline_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Offline_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Offline_8 'n'
#ifdef ORBIT_IDL_C_IMODULE_Evolution
static
#else
extern
#endif
struct CORBA_TypeCode_struct TC_GNOME_Evolution_Offline_struct;
#define TC_GNOME_Evolution_Offline ((CORBA_TypeCode)&TC_GNOME_Evolution_Offline_struct)
#endif
#endif
#undef ex_GNOME_Evolution_Offline_notPrepared
#define ex_GNOME_Evolution_Offline_notPrepared "IDL:GNOME/Evolution/Offline/notPrepared:1.0"
#if !defined(_GNOME_Evolution_Offline_notPrepared_defined)
#define _GNOME_Evolution_Offline_notPrepared_defined 1
typedef struct GNOME_Evolution_Offline_notPrepared_type GNOME_Evolution_Offline_notPrepared;
struct GNOME_Evolution_Offline_notPrepared_type {
int dummy;
};

#if !defined(TC_IMPL_TC_GNOME_Evolution_Offline_notPrepared_0)
#define TC_IMPL_TC_GNOME_Evolution_Offline_notPrepared_0 'E'
#define TC_IMPL_TC_GNOME_Evolution_Offline_notPrepared_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Offline_notPrepared_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Offline_notPrepared_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Offline_notPrepared_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Offline_notPrepared_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Offline_notPrepared_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Offline_notPrepared_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Offline_notPrepared_8 'n'
#ifdef ORBIT_IDL_C_IMODULE_Evolution
static
#else
extern
#endif
struct CORBA_TypeCode_struct TC_GNOME_Evolution_Offline_notPrepared_struct;
#define TC_GNOME_Evolution_Offline_notPrepared ((CORBA_TypeCode)&TC_GNOME_Evolution_Offline_notPrepared_struct)
#endif
#define GNOME_Evolution_Offline_notPrepared__alloc() ((GNOME_Evolution_Offline_notPrepared *)ORBit_small_alloc (TC_GNOME_Evolution_Offline_notPrepared))
#define GNOME_Evolution_Offline_notPrepared__freekids(m,d) ORBit_small_freekids (TC_GNOME_Evolution_Offline_notPrepared,(m),(d))
#endif
#undef ex_GNOME_Evolution_Offline_notSyncing
#define ex_GNOME_Evolution_Offline_notSyncing "IDL:GNOME/Evolution/Offline/notSyncing:1.0"
#if !defined(_GNOME_Evolution_Offline_notSyncing_defined)
#define _GNOME_Evolution_Offline_notSyncing_defined 1
typedef struct GNOME_Evolution_Offline_notSyncing_type GNOME_Evolution_Offline_notSyncing;
struct GNOME_Evolution_Offline_notSyncing_type {
int dummy;
};

#if !defined(TC_IMPL_TC_GNOME_Evolution_Offline_notSyncing_0)
#define TC_IMPL_TC_GNOME_Evolution_Offline_notSyncing_0 'E'
#define TC_IMPL_TC_GNOME_Evolution_Offline_notSyncing_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Offline_notSyncing_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Offline_notSyncing_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Offline_notSyncing_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Offline_notSyncing_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Offline_notSyncing_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Offline_notSyncing_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Offline_notSyncing_8 'n'
#ifdef ORBIT_IDL_C_IMODULE_Evolution
static
#else
extern
#endif
struct CORBA_TypeCode_struct TC_GNOME_Evolution_Offline_notSyncing_struct;
#define TC_GNOME_Evolution_Offline_notSyncing ((CORBA_TypeCode)&TC_GNOME_Evolution_Offline_notSyncing_struct)
#endif
#define GNOME_Evolution_Offline_notSyncing__alloc() ((GNOME_Evolution_Offline_notSyncing *)ORBit_small_alloc (TC_GNOME_Evolution_Offline_notSyncing))
#define GNOME_Evolution_Offline_notSyncing__freekids(m,d) ORBit_small_freekids (TC_GNOME_Evolution_Offline_notSyncing,(m),(d))
#endif
#if !defined(ORBIT_DECL_GNOME_Evolution_Shell) && !defined(_GNOME_Evolution_Shell_defined)
#define ORBIT_DECL_GNOME_Evolution_Shell 1
#define _GNOME_Evolution_Shell_defined 1
#define GNOME_Evolution_Shell__freekids CORBA_Object__freekids
typedef CORBA_Object GNOME_Evolution_Shell;
extern CORBA_unsigned_long GNOME_Evolution_Shell__classid;
#if !defined(TC_IMPL_TC_GNOME_Evolution_Shell_0)
#define TC_IMPL_TC_GNOME_Evolution_Shell_0 'E'
#define TC_IMPL_TC_GNOME_Evolution_Shell_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Shell_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Shell_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Shell_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Shell_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Shell_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Shell_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Shell_8 'n'
#ifdef ORBIT_IDL_C_IMODULE_Evolution
static
#else
extern
#endif
struct CORBA_TypeCode_struct TC_GNOME_Evolution_Shell_struct;
#define TC_GNOME_Evolution_Shell ((CORBA_TypeCode)&TC_GNOME_Evolution_Shell_struct)
#endif
#endif
#undef ex_GNOME_Evolution_Shell_Busy
#define ex_GNOME_Evolution_Shell_Busy "IDL:GNOME/Evolution/Shell/Busy:1.0"
#if !defined(_GNOME_Evolution_Shell_Busy_defined)
#define _GNOME_Evolution_Shell_Busy_defined 1
typedef struct GNOME_Evolution_Shell_Busy_type GNOME_Evolution_Shell_Busy;
struct GNOME_Evolution_Shell_Busy_type {
int dummy;
};

#if !defined(TC_IMPL_TC_GNOME_Evolution_Shell_Busy_0)
#define TC_IMPL_TC_GNOME_Evolution_Shell_Busy_0 'E'
#define TC_IMPL_TC_GNOME_Evolution_Shell_Busy_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Shell_Busy_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Shell_Busy_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Shell_Busy_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Shell_Busy_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Shell_Busy_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Shell_Busy_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Shell_Busy_8 'n'
#ifdef ORBIT_IDL_C_IMODULE_Evolution
static
#else
extern
#endif
struct CORBA_TypeCode_struct TC_GNOME_Evolution_Shell_Busy_struct;
#define TC_GNOME_Evolution_Shell_Busy ((CORBA_TypeCode)&TC_GNOME_Evolution_Shell_Busy_struct)
#endif
#define GNOME_Evolution_Shell_Busy__alloc() ((GNOME_Evolution_Shell_Busy *)ORBit_small_alloc (TC_GNOME_Evolution_Shell_Busy))
#define GNOME_Evolution_Shell_Busy__freekids(m,d) ORBit_small_freekids (TC_GNOME_Evolution_Shell_Busy,(m),(d))
#endif
#undef ex_GNOME_Evolution_Shell_ComponentNotFound
#define ex_GNOME_Evolution_Shell_ComponentNotFound "IDL:GNOME/Evolution/Shell/ComponentNotFound:1.0"
#if !defined(_GNOME_Evolution_Shell_ComponentNotFound_defined)
#define _GNOME_Evolution_Shell_ComponentNotFound_defined 1
typedef struct GNOME_Evolution_Shell_ComponentNotFound_type GNOME_Evolution_Shell_ComponentNotFound;
struct GNOME_Evolution_Shell_ComponentNotFound_type {
int dummy;
};

#if !defined(TC_IMPL_TC_GNOME_Evolution_Shell_ComponentNotFound_0)
#define TC_IMPL_TC_GNOME_Evolution_Shell_ComponentNotFound_0 'E'
#define TC_IMPL_TC_GNOME_Evolution_Shell_ComponentNotFound_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Shell_ComponentNotFound_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Shell_ComponentNotFound_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Shell_ComponentNotFound_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Shell_ComponentNotFound_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Shell_ComponentNotFound_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Shell_ComponentNotFound_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Shell_ComponentNotFound_8 'n'
#ifdef ORBIT_IDL_C_IMODULE_Evolution
static
#else
extern
#endif
struct CORBA_TypeCode_struct TC_GNOME_Evolution_Shell_ComponentNotFound_struct;
#define TC_GNOME_Evolution_Shell_ComponentNotFound ((CORBA_TypeCode)&TC_GNOME_Evolution_Shell_ComponentNotFound_struct)
#endif
#define GNOME_Evolution_Shell_ComponentNotFound__alloc() ((GNOME_Evolution_Shell_ComponentNotFound *)ORBit_small_alloc (TC_GNOME_Evolution_Shell_ComponentNotFound))
#define GNOME_Evolution_Shell_ComponentNotFound__freekids(m,d) ORBit_small_freekids (TC_GNOME_Evolution_Shell_ComponentNotFound,(m),(d))
#endif
#undef ex_GNOME_Evolution_Shell_InternalError
#define ex_GNOME_Evolution_Shell_InternalError "IDL:GNOME/Evolution/Shell/InternalError:1.0"
#if !defined(_GNOME_Evolution_Shell_InternalError_defined)
#define _GNOME_Evolution_Shell_InternalError_defined 1
typedef struct GNOME_Evolution_Shell_InternalError_type GNOME_Evolution_Shell_InternalError;
struct GNOME_Evolution_Shell_InternalError_type {
int dummy;
};

#if !defined(TC_IMPL_TC_GNOME_Evolution_Shell_InternalError_0)
#define TC_IMPL_TC_GNOME_Evolution_Shell_InternalError_0 'E'
#define TC_IMPL_TC_GNOME_Evolution_Shell_InternalError_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Shell_InternalError_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Shell_InternalError_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Shell_InternalError_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Shell_InternalError_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Shell_InternalError_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Shell_InternalError_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Shell_InternalError_8 'n'
#ifdef ORBIT_IDL_C_IMODULE_Evolution
static
#else
extern
#endif
struct CORBA_TypeCode_struct TC_GNOME_Evolution_Shell_InternalError_struct;
#define TC_GNOME_Evolution_Shell_InternalError ((CORBA_TypeCode)&TC_GNOME_Evolution_Shell_InternalError_struct)
#endif
#define GNOME_Evolution_Shell_InternalError__alloc() ((GNOME_Evolution_Shell_InternalError *)ORBit_small_alloc (TC_GNOME_Evolution_Shell_InternalError))
#define GNOME_Evolution_Shell_InternalError__freekids(m,d) ORBit_small_freekids (TC_GNOME_Evolution_Shell_InternalError,(m),(d))
#endif
#undef ex_GNOME_Evolution_Shell_InvalidURI
#define ex_GNOME_Evolution_Shell_InvalidURI "IDL:GNOME/Evolution/Shell/InvalidURI:1.0"
#if !defined(_GNOME_Evolution_Shell_InvalidURI_defined)
#define _GNOME_Evolution_Shell_InvalidURI_defined 1
typedef struct GNOME_Evolution_Shell_InvalidURI_type GNOME_Evolution_Shell_InvalidURI;
struct GNOME_Evolution_Shell_InvalidURI_type {
int dummy;
};

#if !defined(TC_IMPL_TC_GNOME_Evolution_Shell_InvalidURI_0)
#define TC_IMPL_TC_GNOME_Evolution_Shell_InvalidURI_0 'E'
#define TC_IMPL_TC_GNOME_Evolution_Shell_InvalidURI_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Shell_InvalidURI_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Shell_InvalidURI_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Shell_InvalidURI_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Shell_InvalidURI_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Shell_InvalidURI_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Shell_InvalidURI_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Shell_InvalidURI_8 'n'
#ifdef ORBIT_IDL_C_IMODULE_Evolution
static
#else
extern
#endif
struct CORBA_TypeCode_struct TC_GNOME_Evolution_Shell_InvalidURI_struct;
#define TC_GNOME_Evolution_Shell_InvalidURI ((CORBA_TypeCode)&TC_GNOME_Evolution_Shell_InvalidURI_struct)
#endif
#define GNOME_Evolution_Shell_InvalidURI__alloc() ((GNOME_Evolution_Shell_InvalidURI *)ORBit_small_alloc (TC_GNOME_Evolution_Shell_InvalidURI))
#define GNOME_Evolution_Shell_InvalidURI__freekids(m,d) ORBit_small_freekids (TC_GNOME_Evolution_Shell_InvalidURI,(m),(d))
#endif
#undef ex_GNOME_Evolution_Shell_NotFound
#define ex_GNOME_Evolution_Shell_NotFound "IDL:GNOME/Evolution/Shell/NotFound:1.0"
#if !defined(_GNOME_Evolution_Shell_NotFound_defined)
#define _GNOME_Evolution_Shell_NotFound_defined 1
typedef struct GNOME_Evolution_Shell_NotFound_type GNOME_Evolution_Shell_NotFound;
struct GNOME_Evolution_Shell_NotFound_type {
int dummy;
};

#if !defined(TC_IMPL_TC_GNOME_Evolution_Shell_NotFound_0)
#define TC_IMPL_TC_GNOME_Evolution_Shell_NotFound_0 'E'
#define TC_IMPL_TC_GNOME_Evolution_Shell_NotFound_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Shell_NotFound_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Shell_NotFound_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Shell_NotFound_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Shell_NotFound_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Shell_NotFound_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Shell_NotFound_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Shell_NotFound_8 'n'
#ifdef ORBIT_IDL_C_IMODULE_Evolution
static
#else
extern
#endif
struct CORBA_TypeCode_struct TC_GNOME_Evolution_Shell_NotFound_struct;
#define TC_GNOME_Evolution_Shell_NotFound ((CORBA_TypeCode)&TC_GNOME_Evolution_Shell_NotFound_struct)
#endif
#define GNOME_Evolution_Shell_NotFound__alloc() ((GNOME_Evolution_Shell_NotFound *)ORBit_small_alloc (TC_GNOME_Evolution_Shell_NotFound))
#define GNOME_Evolution_Shell_NotFound__freekids(m,d) ORBit_small_freekids (TC_GNOME_Evolution_Shell_NotFound,(m),(d))
#endif
#undef ex_GNOME_Evolution_Shell_NotReady
#define ex_GNOME_Evolution_Shell_NotReady "IDL:GNOME/Evolution/Shell/NotReady:1.0"
#if !defined(_GNOME_Evolution_Shell_NotReady_defined)
#define _GNOME_Evolution_Shell_NotReady_defined 1
typedef struct GNOME_Evolution_Shell_NotReady_type GNOME_Evolution_Shell_NotReady;
struct GNOME_Evolution_Shell_NotReady_type {
int dummy;
};

#if !defined(TC_IMPL_TC_GNOME_Evolution_Shell_NotReady_0)
#define TC_IMPL_TC_GNOME_Evolution_Shell_NotReady_0 'E'
#define TC_IMPL_TC_GNOME_Evolution_Shell_NotReady_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Shell_NotReady_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Shell_NotReady_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Shell_NotReady_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Shell_NotReady_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Shell_NotReady_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Shell_NotReady_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Shell_NotReady_8 'n'
#ifdef ORBIT_IDL_C_IMODULE_Evolution
static
#else
extern
#endif
struct CORBA_TypeCode_struct TC_GNOME_Evolution_Shell_NotReady_struct;
#define TC_GNOME_Evolution_Shell_NotReady ((CORBA_TypeCode)&TC_GNOME_Evolution_Shell_NotReady_struct)
#endif
#define GNOME_Evolution_Shell_NotReady__alloc() ((GNOME_Evolution_Shell_NotReady *)ORBit_small_alloc (TC_GNOME_Evolution_Shell_NotReady))
#define GNOME_Evolution_Shell_NotReady__freekids(m,d) ORBit_small_freekids (TC_GNOME_Evolution_Shell_NotReady,(m),(d))
#endif
#undef ex_GNOME_Evolution_Shell_UnsupportedSchema
#define ex_GNOME_Evolution_Shell_UnsupportedSchema "IDL:GNOME/Evolution/Shell/UnsupportedSchema:1.0"
#if !defined(_GNOME_Evolution_Shell_UnsupportedSchema_defined)
#define _GNOME_Evolution_Shell_UnsupportedSchema_defined 1
typedef struct GNOME_Evolution_Shell_UnsupportedSchema_type GNOME_Evolution_Shell_UnsupportedSchema;
struct GNOME_Evolution_Shell_UnsupportedSchema_type {
int dummy;
};

#if !defined(TC_IMPL_TC_GNOME_Evolution_Shell_UnsupportedSchema_0)
#define TC_IMPL_TC_GNOME_Evolution_Shell_UnsupportedSchema_0 'E'
#define TC_IMPL_TC_GNOME_Evolution_Shell_UnsupportedSchema_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Shell_UnsupportedSchema_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Shell_UnsupportedSchema_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Shell_UnsupportedSchema_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Shell_UnsupportedSchema_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Shell_UnsupportedSchema_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Shell_UnsupportedSchema_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Shell_UnsupportedSchema_8 'n'
#ifdef ORBIT_IDL_C_IMODULE_Evolution
static
#else
extern
#endif
struct CORBA_TypeCode_struct TC_GNOME_Evolution_Shell_UnsupportedSchema_struct;
#define TC_GNOME_Evolution_Shell_UnsupportedSchema ((CORBA_TypeCode)&TC_GNOME_Evolution_Shell_UnsupportedSchema_struct)
#endif
#define GNOME_Evolution_Shell_UnsupportedSchema__alloc() ((GNOME_Evolution_Shell_UnsupportedSchema *)ORBit_small_alloc (TC_GNOME_Evolution_Shell_UnsupportedSchema))
#define GNOME_Evolution_Shell_UnsupportedSchema__freekids(m,d) ORBit_small_freekids (TC_GNOME_Evolution_Shell_UnsupportedSchema,(m),(d))
#endif
#if !defined(ORBIT_DECL_GNOME_Evolution_Wizard) && !defined(_GNOME_Evolution_Wizard_defined)
#define ORBIT_DECL_GNOME_Evolution_Wizard 1
#define _GNOME_Evolution_Wizard_defined 1
#define GNOME_Evolution_Wizard__freekids CORBA_Object__freekids
typedef CORBA_Object GNOME_Evolution_Wizard;
extern CORBA_unsigned_long GNOME_Evolution_Wizard__classid;
#if !defined(TC_IMPL_TC_GNOME_Evolution_Wizard_0)
#define TC_IMPL_TC_GNOME_Evolution_Wizard_0 'E'
#define TC_IMPL_TC_GNOME_Evolution_Wizard_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Wizard_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Wizard_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Wizard_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Wizard_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Wizard_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Wizard_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Wizard_8 'n'
#ifdef ORBIT_IDL_C_IMODULE_Evolution
static
#else
extern
#endif
struct CORBA_TypeCode_struct TC_GNOME_Evolution_Wizard_struct;
#define TC_GNOME_Evolution_Wizard ((CORBA_TypeCode)&TC_GNOME_Evolution_Wizard_struct)
#endif
#endif
#if !defined(_GNOME_Evolution_Wizard_Page_defined)
#define _GNOME_Evolution_Wizard_Page_defined 1
typedef struct GNOME_Evolution_Wizard_Page_type GNOME_Evolution_Wizard_Page;
struct GNOME_Evolution_Wizard_Page_type {
CORBA_string title;
GNOME_Evolution_Icon icon;
Bonobo_Control control;
};

#if !defined(TC_IMPL_TC_GNOME_Evolution_Wizard_Page_0)
#define TC_IMPL_TC_GNOME_Evolution_Wizard_Page_0 'E'
#define TC_IMPL_TC_GNOME_Evolution_Wizard_Page_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Wizard_Page_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Wizard_Page_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Wizard_Page_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Wizard_Page_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Wizard_Page_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Wizard_Page_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Wizard_Page_8 'n'
#ifdef ORBIT_IDL_C_IMODULE_Evolution
static
#else
extern
#endif
struct CORBA_TypeCode_struct TC_GNOME_Evolution_Wizard_Page_struct;
#define TC_GNOME_Evolution_Wizard_Page ((CORBA_TypeCode)&TC_GNOME_Evolution_Wizard_Page_struct)
#endif
#define GNOME_Evolution_Wizard_Page__alloc() ((GNOME_Evolution_Wizard_Page *)ORBit_small_alloc (TC_GNOME_Evolution_Wizard_Page))
#define GNOME_Evolution_Wizard_Page__freekids(m,d) ORBit_small_freekids (TC_GNOME_Evolution_Wizard_Page,(m),(d))
#endif
#if !defined(ORBIT_DECL_CORBA_sequence_GNOME_Evolution_Wizard_Page)
#define ORBIT_DECL_CORBA_sequence_GNOME_Evolution_Wizard_Page 1
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Wizard_Page_0 'E'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Wizard_Page_1 'v'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Wizard_Page_2 'o'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Wizard_Page_3 'l'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Wizard_Page_4 'u'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Wizard_Page_5 't'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Wizard_Page_6 'i'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Wizard_Page_7 'o'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Wizard_Page_8 'n'
#if !defined(_CORBA_sequence_GNOME_Evolution_Wizard_Page_defined)
#define _CORBA_sequence_GNOME_Evolution_Wizard_Page_defined 1
typedef struct { CORBA_unsigned_long _maximum, _length; GNOME_Evolution_Wizard_Page* _buffer; CORBA_boolean _release; } CORBA_sequence_GNOME_Evolution_Wizard_Page;
#endif
#if !defined(TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Wizard_Page_0)
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Wizard_Page_0 'E'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Wizard_Page_1 'v'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Wizard_Page_2 'o'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Wizard_Page_3 'l'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Wizard_Page_4 'u'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Wizard_Page_5 't'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Wizard_Page_6 'i'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Wizard_Page_7 'o'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Wizard_Page_8 'n'
#ifdef ORBIT_IDL_C_IMODULE_Evolution
static
#else
extern
#endif
struct CORBA_TypeCode_struct TC_CORBA_sequence_GNOME_Evolution_Wizard_Page_struct;
#define TC_CORBA_sequence_GNOME_Evolution_Wizard_Page ((CORBA_TypeCode)&TC_CORBA_sequence_GNOME_Evolution_Wizard_Page_struct)
#endif
#define CORBA_sequence_GNOME_Evolution_Wizard_Page__alloc() ((CORBA_sequence_GNOME_Evolution_Wizard_Page *)ORBit_small_alloc (TC_CORBA_sequence_GNOME_Evolution_Wizard_Page))
#define CORBA_sequence_GNOME_Evolution_Wizard_Page__freekids(m,d) ORBit_small_freekids (TC_CORBA_sequence_GNOME_Evolution_Wizard_Page,(m),(d))
#define CORBA_sequence_GNOME_Evolution_Wizard_Page_allocbuf(l) ((GNOME_Evolution_Wizard_Page*)ORBit_small_allocbuf (TC_CORBA_sequence_GNOME_Evolution_Wizard_Page, (l)))
#define CORBA_sequence_GNOME_Evolution_Wizard_Page_allocbuf(l) ((GNOME_Evolution_Wizard_Page*)ORBit_small_allocbuf (TC_CORBA_sequence_GNOME_Evolution_Wizard_Page, (l)))
#endif
#if !defined(_GNOME_Evolution_Wizard_PageList_defined)
#define _GNOME_Evolution_Wizard_PageList_defined 1
typedef CORBA_sequence_GNOME_Evolution_Wizard_Page GNOME_Evolution_Wizard_PageList;
#define GNOME_Evolution_Wizard_PageList_marshal(x,y,z) CORBA_sequence_GNOME_Evolution_Wizard_Page_marshal((x),(y),(z))
#define GNOME_Evolution_Wizard_PageList_demarshal(x,y,z,i) CORBA_sequence_GNOME_Evolution_Wizard_Page_demarshal((x),(y),(z),(i))
#if !defined(TC_IMPL_TC_GNOME_Evolution_Wizard_PageList_0)
#define TC_IMPL_TC_GNOME_Evolution_Wizard_PageList_0 'E'
#define TC_IMPL_TC_GNOME_Evolution_Wizard_PageList_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Wizard_PageList_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Wizard_PageList_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Wizard_PageList_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Wizard_PageList_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Wizard_PageList_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Wizard_PageList_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Wizard_PageList_8 'n'
#ifdef ORBIT_IDL_C_IMODULE_Evolution
static
#else
extern
#endif
struct CORBA_TypeCode_struct TC_GNOME_Evolution_Wizard_PageList_struct;
#define TC_GNOME_Evolution_Wizard_PageList ((CORBA_TypeCode)&TC_GNOME_Evolution_Wizard_PageList_struct)
#endif
#define GNOME_Evolution_Wizard_PageList__alloc() ((GNOME_Evolution_Wizard_PageList *)ORBit_small_alloc (TC_CORBA_sequence_GNOME_Evolution_Wizard_Page))
#define GNOME_Evolution_Wizard_PageList__freekids(m,d) ORBit_small_freekids (TC_CORBA_sequence_GNOME_Evolution_Wizard_Page,(m),(d))
#define GNOME_Evolution_Wizard_PageList_allocbuf(l) ((GNOME_Evolution_Wizard_Page*)ORBit_small_allocbuf (TC_CORBA_sequence_GNOME_Evolution_Wizard_Page, (l)))
#endif
#if !defined(_GNOME_Evolution_Wizard_Action_defined)
#define _GNOME_Evolution_Wizard_Action_defined 1
typedef enum {
  GNOME_Evolution_Wizard_NEXT,
  GNOME_Evolution_Wizard_PREPARE,
  GNOME_Evolution_Wizard_BACK,
  GNOME_Evolution_Wizard_FINISH,
  GNOME_Evolution_Wizard_CANCEL,
  GNOME_Evolution_Wizard_HELP
} GNOME_Evolution_Wizard_Action;
#if !defined(TC_IMPL_TC_GNOME_Evolution_Wizard_Action_0)
#define TC_IMPL_TC_GNOME_Evolution_Wizard_Action_0 'E'
#define TC_IMPL_TC_GNOME_Evolution_Wizard_Action_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Wizard_Action_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Wizard_Action_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Wizard_Action_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Wizard_Action_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Wizard_Action_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Wizard_Action_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Wizard_Action_8 'n'
#ifdef ORBIT_IDL_C_IMODULE_Evolution
static
#else
extern
#endif
struct CORBA_TypeCode_struct TC_GNOME_Evolution_Wizard_Action_struct;
#define TC_GNOME_Evolution_Wizard_Action ((CORBA_TypeCode)&TC_GNOME_Evolution_Wizard_Action_struct)
#endif
#endif
#undef ex_GNOME_Evolution_Wizard_NoPage
#define ex_GNOME_Evolution_Wizard_NoPage "IDL:GNOME/Evolution/Wizard/NoPage:1.0"
#if !defined(_GNOME_Evolution_Wizard_NoPage_defined)
#define _GNOME_Evolution_Wizard_NoPage_defined 1
typedef struct GNOME_Evolution_Wizard_NoPage_type GNOME_Evolution_Wizard_NoPage;
struct GNOME_Evolution_Wizard_NoPage_type {
int dummy;
};

#if !defined(TC_IMPL_TC_GNOME_Evolution_Wizard_NoPage_0)
#define TC_IMPL_TC_GNOME_Evolution_Wizard_NoPage_0 'E'
#define TC_IMPL_TC_GNOME_Evolution_Wizard_NoPage_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Wizard_NoPage_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Wizard_NoPage_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Wizard_NoPage_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Wizard_NoPage_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Wizard_NoPage_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Wizard_NoPage_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Wizard_NoPage_8 'n'
#ifdef ORBIT_IDL_C_IMODULE_Evolution
static
#else
extern
#endif
struct CORBA_TypeCode_struct TC_GNOME_Evolution_Wizard_NoPage_struct;
#define TC_GNOME_Evolution_Wizard_NoPage ((CORBA_TypeCode)&TC_GNOME_Evolution_Wizard_NoPage_struct)
#endif
#define GNOME_Evolution_Wizard_NoPage__alloc() ((GNOME_Evolution_Wizard_NoPage *)ORBit_small_alloc (TC_GNOME_Evolution_Wizard_NoPage))
#define GNOME_Evolution_Wizard_NoPage__freekids(m,d) ORBit_small_freekids (TC_GNOME_Evolution_Wizard_NoPage,(m),(d))
#endif

/** POA structures **/
#ifndef _defined_POA_GNOME_Evolution_Component
#define _defined_POA_GNOME_Evolution_Component 1
typedef struct {
  void *_private;
void (*upgradeFromVersion)(PortableServer_Servant _servant, const CORBA_short major, const CORBA_short minor, const CORBA_short revision, CORBA_Environment *ev);
void (*createControls)(PortableServer_Servant _servant, Bonobo_Control* sidebar_control, Bonobo_Control* view_control, Bonobo_Control* statusbar_control, CORBA_Environment *ev);
CORBA_boolean (*requestQuit)(PortableServer_Servant _servant, CORBA_Environment *ev);
CORBA_boolean (*quit)(PortableServer_Servant _servant, CORBA_Environment *ev);
void (*interactive)(PortableServer_Servant _servant, const CORBA_boolean now_interactive, const CORBA_unsigned_long new_view_xid, CORBA_Environment *ev);
GNOME_Evolution_CreatableItemTypeList* (*_get_userCreatableItems)(PortableServer_Servant _servant, CORBA_Environment *ev);
void (*requestCreateItem)(PortableServer_Servant _servant, const CORBA_char * item_type_name, CORBA_Environment *ev);
void (*handleURI)(PortableServer_Servant _servant, const CORBA_char * uri, CORBA_Environment *ev);
void (*sendAndReceive)(PortableServer_Servant _servant, CORBA_Environment *ev);
} POA_GNOME_Evolution_Component__epv;
typedef struct {
  PortableServer_ServantBase__epv *_base_epv;
  POA_Bonobo_Unknown__epv *Bonobo_Unknown_epv;
  POA_GNOME_Evolution_Component__epv *GNOME_Evolution_Component_epv;
} POA_GNOME_Evolution_Component__vepv;
typedef struct {
  void *_private;
  POA_GNOME_Evolution_Component__vepv *vepv;
} POA_GNOME_Evolution_Component;
extern void POA_GNOME_Evolution_Component__init(PortableServer_Servant servant, CORBA_Environment *ev);
extern void POA_GNOME_Evolution_Component__fini(PortableServer_Servant servant, CORBA_Environment *ev);
#endif /* _defined_POA_GNOME_Evolution_Component */
#ifndef _defined_POA_GNOME_Evolution_ConfigControl
#define _defined_POA_GNOME_Evolution_ConfigControl 1
typedef struct {
  void *_private;
Bonobo_Control (*_get_control)(PortableServer_Servant _servant, CORBA_Environment *ev);
Bonobo_EventSource (*_get_eventSource)(PortableServer_Servant _servant, CORBA_Environment *ev);
} POA_GNOME_Evolution_ConfigControl__epv;
typedef struct {
  PortableServer_ServantBase__epv *_base_epv;
  POA_Bonobo_Unknown__epv *Bonobo_Unknown_epv;
  POA_GNOME_Evolution_ConfigControl__epv *GNOME_Evolution_ConfigControl_epv;
} POA_GNOME_Evolution_ConfigControl__vepv;
typedef struct {
  void *_private;
  POA_GNOME_Evolution_ConfigControl__vepv *vepv;
} POA_GNOME_Evolution_ConfigControl;
extern void POA_GNOME_Evolution_ConfigControl__init(PortableServer_Servant servant, CORBA_Environment *ev);
extern void POA_GNOME_Evolution_ConfigControl__fini(PortableServer_Servant servant, CORBA_Environment *ev);
#endif /* _defined_POA_GNOME_Evolution_ConfigControl */
#ifndef _defined_POA_GNOME_Evolution_OfflineProgressListener
#define _defined_POA_GNOME_Evolution_OfflineProgressListener 1
typedef struct {
  void *_private;
void (*updateProgress)(PortableServer_Servant _servant, const GNOME_Evolution_ConnectionList* current_active_connections, CORBA_Environment *ev);
} POA_GNOME_Evolution_OfflineProgressListener__epv;
typedef struct {
  PortableServer_ServantBase__epv *_base_epv;
  POA_GNOME_Evolution_OfflineProgressListener__epv *GNOME_Evolution_OfflineProgressListener_epv;
} POA_GNOME_Evolution_OfflineProgressListener__vepv;
typedef struct {
  void *_private;
  POA_GNOME_Evolution_OfflineProgressListener__vepv *vepv;
} POA_GNOME_Evolution_OfflineProgressListener;
extern void POA_GNOME_Evolution_OfflineProgressListener__init(PortableServer_Servant servant, CORBA_Environment *ev);
extern void POA_GNOME_Evolution_OfflineProgressListener__fini(PortableServer_Servant servant, CORBA_Environment *ev);
#endif /* _defined_POA_GNOME_Evolution_OfflineProgressListener */
#ifndef _defined_POA_GNOME_Evolution_Offline
#define _defined_POA_GNOME_Evolution_Offline 1
typedef struct {
  void *_private;
CORBA_boolean (*_get_isOffline)(PortableServer_Servant _servant, CORBA_Environment *ev);
void (*_set_isOffline)(PortableServer_Servant _servant, const CORBA_boolean value, CORBA_Environment *ev);
void (*prepareForOffline)(PortableServer_Servant _servant, GNOME_Evolution_ConnectionList** active_connection_list, CORBA_Environment *ev);
void (*goOffline)(PortableServer_Servant _servant, const GNOME_Evolution_OfflineProgressListener listener, CORBA_Environment *ev);
void (*goOnline)(PortableServer_Servant _servant, CORBA_Environment *ev);
} POA_GNOME_Evolution_Offline__epv;
typedef struct {
  PortableServer_ServantBase__epv *_base_epv;
  POA_Bonobo_Unknown__epv *Bonobo_Unknown_epv;
  POA_GNOME_Evolution_Offline__epv *GNOME_Evolution_Offline_epv;
} POA_GNOME_Evolution_Offline__vepv;
typedef struct {
  void *_private;
  POA_GNOME_Evolution_Offline__vepv *vepv;
} POA_GNOME_Evolution_Offline;
extern void POA_GNOME_Evolution_Offline__init(PortableServer_Servant servant, CORBA_Environment *ev);
extern void POA_GNOME_Evolution_Offline__fini(PortableServer_Servant servant, CORBA_Environment *ev);
#endif /* _defined_POA_GNOME_Evolution_Offline */
#ifndef _defined_POA_GNOME_Evolution_Shell
#define _defined_POA_GNOME_Evolution_Shell 1
typedef struct {
  void *_private;
void (*createNewWindow)(PortableServer_Servant _servant, const CORBA_char * component_id, CORBA_Environment *ev);
void (*handleURI)(PortableServer_Servant _servant, const CORBA_char * uri, CORBA_Environment *ev);
void (*setLineStatus)(PortableServer_Servant _servant, const CORBA_boolean online, CORBA_Environment *ev);
} POA_GNOME_Evolution_Shell__epv;
typedef struct {
  PortableServer_ServantBase__epv *_base_epv;
  POA_Bonobo_Unknown__epv *Bonobo_Unknown_epv;
  POA_GNOME_Evolution_Shell__epv *GNOME_Evolution_Shell_epv;
} POA_GNOME_Evolution_Shell__vepv;
typedef struct {
  void *_private;
  POA_GNOME_Evolution_Shell__vepv *vepv;
} POA_GNOME_Evolution_Shell;
extern void POA_GNOME_Evolution_Shell__init(PortableServer_Servant servant, CORBA_Environment *ev);
extern void POA_GNOME_Evolution_Shell__fini(PortableServer_Servant servant, CORBA_Environment *ev);
#endif /* _defined_POA_GNOME_Evolution_Shell */
#ifndef _defined_POA_GNOME_Evolution_Wizard
#define _defined_POA_GNOME_Evolution_Wizard 1
typedef struct {
  void *_private;
GNOME_Evolution_Wizard_PageList* (*_get_pages)(PortableServer_Servant _servant, CORBA_Environment *ev);
void (*notifyAction)(PortableServer_Servant _servant, const CORBA_long pagenumber, const GNOME_Evolution_Wizard_Action action, CORBA_Environment *ev);
} POA_GNOME_Evolution_Wizard__epv;
typedef struct {
  PortableServer_ServantBase__epv *_base_epv;
  POA_Bonobo_Unknown__epv *Bonobo_Unknown_epv;
  POA_GNOME_Evolution_Wizard__epv *GNOME_Evolution_Wizard_epv;
} POA_GNOME_Evolution_Wizard__vepv;
typedef struct {
  void *_private;
  POA_GNOME_Evolution_Wizard__vepv *vepv;
} POA_GNOME_Evolution_Wizard;
extern void POA_GNOME_Evolution_Wizard__init(PortableServer_Servant servant, CORBA_Environment *ev);
extern void POA_GNOME_Evolution_Wizard__fini(PortableServer_Servant servant, CORBA_Environment *ev);
#endif /* _defined_POA_GNOME_Evolution_Wizard */

/** skel prototypes **/
void _ORBIT_skel_small_GNOME_Evolution_Component_upgradeFromVersion(POA_GNOME_Evolution_Component *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_upgradeFromVersion)(PortableServer_Servant _servant, const CORBA_short major, const CORBA_short minor, const CORBA_short revision, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Component_createControls(POA_GNOME_Evolution_Component *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_createControls)(PortableServer_Servant _servant, Bonobo_Control* sidebar_control, Bonobo_Control* view_control, Bonobo_Control* statusbar_control, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Component_requestQuit(POA_GNOME_Evolution_Component *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, CORBA_boolean (*_impl_requestQuit)(PortableServer_Servant _servant, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Component_quit(POA_GNOME_Evolution_Component *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, CORBA_boolean (*_impl_quit)(PortableServer_Servant _servant, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Component_interactive(POA_GNOME_Evolution_Component *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_interactive)(PortableServer_Servant _servant, const CORBA_boolean now_interactive, const CORBA_unsigned_long new_view_xid, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Component__get_userCreatableItems(POA_GNOME_Evolution_Component *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, GNOME_Evolution_CreatableItemTypeList* (*_impl__get_userCreatableItems)(PortableServer_Servant _servant, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Component_requestCreateItem(POA_GNOME_Evolution_Component *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_requestCreateItem)(PortableServer_Servant _servant, const CORBA_char * item_type_name, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Component_handleURI(POA_GNOME_Evolution_Component *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_handleURI)(PortableServer_Servant _servant, const CORBA_char * uri, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Component_sendAndReceive(POA_GNOME_Evolution_Component *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_sendAndReceive)(PortableServer_Servant _servant, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_ConfigControl__get_control(POA_GNOME_Evolution_ConfigControl *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, Bonobo_Control (*_impl__get_control)(PortableServer_Servant _servant, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_ConfigControl__get_eventSource(POA_GNOME_Evolution_ConfigControl *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, Bonobo_EventSource (*_impl__get_eventSource)(PortableServer_Servant _servant, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_OfflineProgressListener_updateProgress(POA_GNOME_Evolution_OfflineProgressListener *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_updateProgress)(PortableServer_Servant _servant, const GNOME_Evolution_ConnectionList* current_active_connections, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Offline__get_isOffline(POA_GNOME_Evolution_Offline *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, CORBA_boolean (*_impl__get_isOffline)(PortableServer_Servant _servant, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Offline__set_isOffline(POA_GNOME_Evolution_Offline *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl__set_isOffline)(PortableServer_Servant _servant, const CORBA_boolean value, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Offline_prepareForOffline(POA_GNOME_Evolution_Offline *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_prepareForOffline)(PortableServer_Servant _servant, GNOME_Evolution_ConnectionList** active_connection_list, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Offline_goOffline(POA_GNOME_Evolution_Offline *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_goOffline)(PortableServer_Servant _servant, const GNOME_Evolution_OfflineProgressListener listener, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Offline_goOnline(POA_GNOME_Evolution_Offline *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_goOnline)(PortableServer_Servant _servant, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Shell_createNewWindow(POA_GNOME_Evolution_Shell *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_createNewWindow)(PortableServer_Servant _servant, const CORBA_char * component_id, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Shell_handleURI(POA_GNOME_Evolution_Shell *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_handleURI)(PortableServer_Servant _servant, const CORBA_char * uri, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Shell_setLineStatus(POA_GNOME_Evolution_Shell *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_setLineStatus)(PortableServer_Servant _servant, const CORBA_boolean online, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Wizard__get_pages(POA_GNOME_Evolution_Wizard *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, GNOME_Evolution_Wizard_PageList* (*_impl__get_pages)(PortableServer_Servant _servant, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Wizard_notifyAction(POA_GNOME_Evolution_Wizard *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_notifyAction)(PortableServer_Servant _servant, const CORBA_long pagenumber, const GNOME_Evolution_Wizard_Action action, CORBA_Environment *ev));

/** stub prototypes **/
#define GNOME_Evolution_Component_ref Bonobo_Unknown_ref
#define GNOME_Evolution_Component_unref Bonobo_Unknown_unref
#define GNOME_Evolution_Component_queryInterface Bonobo_Unknown_queryInterface
void GNOME_Evolution_Component_upgradeFromVersion(GNOME_Evolution_Component _obj, const CORBA_short major, const CORBA_short minor, const CORBA_short revision, CORBA_Environment *ev);
void GNOME_Evolution_Component_createControls(GNOME_Evolution_Component _obj, Bonobo_Control* sidebar_control, Bonobo_Control* view_control, Bonobo_Control* statusbar_control, CORBA_Environment *ev);
CORBA_boolean GNOME_Evolution_Component_requestQuit(GNOME_Evolution_Component _obj, CORBA_Environment *ev);
CORBA_boolean GNOME_Evolution_Component_quit(GNOME_Evolution_Component _obj, CORBA_Environment *ev);
void GNOME_Evolution_Component_interactive(GNOME_Evolution_Component _obj, const CORBA_boolean now_interactive, const CORBA_unsigned_long new_view_xid, CORBA_Environment *ev);
GNOME_Evolution_CreatableItemTypeList* GNOME_Evolution_Component__get_userCreatableItems(GNOME_Evolution_Component _obj, CORBA_Environment *ev);
void GNOME_Evolution_Component_requestCreateItem(GNOME_Evolution_Component _obj, const CORBA_char * item_type_name, CORBA_Environment *ev);
void GNOME_Evolution_Component_handleURI(GNOME_Evolution_Component _obj, const CORBA_char * uri, CORBA_Environment *ev);
void GNOME_Evolution_Component_sendAndReceive(GNOME_Evolution_Component _obj, CORBA_Environment *ev);
#define GNOME_Evolution_ConfigControl_ref Bonobo_Unknown_ref
#define GNOME_Evolution_ConfigControl_unref Bonobo_Unknown_unref
#define GNOME_Evolution_ConfigControl_queryInterface Bonobo_Unknown_queryInterface
Bonobo_Control GNOME_Evolution_ConfigControl__get_control(GNOME_Evolution_ConfigControl _obj, CORBA_Environment *ev);
Bonobo_EventSource GNOME_Evolution_ConfigControl__get_eventSource(GNOME_Evolution_ConfigControl _obj, CORBA_Environment *ev);
void GNOME_Evolution_OfflineProgressListener_updateProgress(GNOME_Evolution_OfflineProgressListener _obj, const GNOME_Evolution_ConnectionList* current_active_connections, CORBA_Environment *ev);
#define GNOME_Evolution_Offline_ref Bonobo_Unknown_ref
#define GNOME_Evolution_Offline_unref Bonobo_Unknown_unref
#define GNOME_Evolution_Offline_queryInterface Bonobo_Unknown_queryInterface
CORBA_boolean GNOME_Evolution_Offline__get_isOffline(GNOME_Evolution_Offline _obj, CORBA_Environment *ev);
void GNOME_Evolution_Offline__set_isOffline(GNOME_Evolution_Offline _obj, const CORBA_boolean value, CORBA_Environment *ev);
void GNOME_Evolution_Offline_prepareForOffline(GNOME_Evolution_Offline _obj, GNOME_Evolution_ConnectionList** active_connection_list, CORBA_Environment *ev);
void GNOME_Evolution_Offline_goOffline(GNOME_Evolution_Offline _obj, const GNOME_Evolution_OfflineProgressListener listener, CORBA_Environment *ev);
void GNOME_Evolution_Offline_goOnline(GNOME_Evolution_Offline _obj, CORBA_Environment *ev);
#define GNOME_Evolution_Shell_ref Bonobo_Unknown_ref
#define GNOME_Evolution_Shell_unref Bonobo_Unknown_unref
#define GNOME_Evolution_Shell_queryInterface Bonobo_Unknown_queryInterface
void GNOME_Evolution_Shell_createNewWindow(GNOME_Evolution_Shell _obj, const CORBA_char * component_id, CORBA_Environment *ev);
void GNOME_Evolution_Shell_handleURI(GNOME_Evolution_Shell _obj, const CORBA_char * uri, CORBA_Environment *ev);
void GNOME_Evolution_Shell_setLineStatus(GNOME_Evolution_Shell _obj, const CORBA_boolean online, CORBA_Environment *ev);
#define GNOME_Evolution_Wizard_ref Bonobo_Unknown_ref
#define GNOME_Evolution_Wizard_unref Bonobo_Unknown_unref
#define GNOME_Evolution_Wizard_queryInterface Bonobo_Unknown_queryInterface
GNOME_Evolution_Wizard_PageList* GNOME_Evolution_Wizard__get_pages(GNOME_Evolution_Wizard _obj, CORBA_Environment *ev);
void GNOME_Evolution_Wizard_notifyAction(GNOME_Evolution_Wizard _obj, const CORBA_long pagenumber, const GNOME_Evolution_Wizard_Action action, CORBA_Environment *ev);
#include <orbit/orb-core/orbit-interface.h>

#ifdef ORBIT_IDL_C_IMODULE_Evolution
static 
#else
extern 
#endif
ORBit_IInterface GNOME_Evolution_Component__iinterface;
#define GNOME_Evolution_Component_IMETHODS_LEN 9
#ifdef ORBIT_IDL_C_IMODULE_Evolution
static 
#else
extern 
#endif
ORBit_IMethod GNOME_Evolution_Component__imethods[GNOME_Evolution_Component_IMETHODS_LEN];
#ifdef ORBIT_IDL_C_IMODULE_Evolution
static 
#else
extern 
#endif
ORBit_IInterface GNOME_Evolution_ConfigControl__iinterface;
#define GNOME_Evolution_ConfigControl_IMETHODS_LEN 2
#ifdef ORBIT_IDL_C_IMODULE_Evolution
static 
#else
extern 
#endif
ORBit_IMethod GNOME_Evolution_ConfigControl__imethods[GNOME_Evolution_ConfigControl_IMETHODS_LEN];
#ifdef ORBIT_IDL_C_IMODULE_Evolution
static 
#else
extern 
#endif
ORBit_IInterface GNOME_Evolution_OfflineProgressListener__iinterface;
#define GNOME_Evolution_OfflineProgressListener_IMETHODS_LEN 1
#ifdef ORBIT_IDL_C_IMODULE_Evolution
static 
#else
extern 
#endif
ORBit_IMethod GNOME_Evolution_OfflineProgressListener__imethods[GNOME_Evolution_OfflineProgressListener_IMETHODS_LEN];
#ifdef ORBIT_IDL_C_IMODULE_Evolution
static 
#else
extern 
#endif
ORBit_IInterface GNOME_Evolution_Offline__iinterface;
#define GNOME_Evolution_Offline_IMETHODS_LEN 5
#ifdef ORBIT_IDL_C_IMODULE_Evolution
static 
#else
extern 
#endif
ORBit_IMethod GNOME_Evolution_Offline__imethods[GNOME_Evolution_Offline_IMETHODS_LEN];
#ifdef ORBIT_IDL_C_IMODULE_Evolution
static 
#else
extern 
#endif
ORBit_IInterface GNOME_Evolution_Shell__iinterface;
#define GNOME_Evolution_Shell_IMETHODS_LEN 3
#ifdef ORBIT_IDL_C_IMODULE_Evolution
static 
#else
extern 
#endif
ORBit_IMethod GNOME_Evolution_Shell__imethods[GNOME_Evolution_Shell_IMETHODS_LEN];
#ifdef ORBIT_IDL_C_IMODULE_Evolution
static 
#else
extern 
#endif
ORBit_IInterface GNOME_Evolution_Wizard__iinterface;
#define GNOME_Evolution_Wizard_IMETHODS_LEN 2
#ifdef ORBIT_IDL_C_IMODULE_Evolution
static 
#else
extern 
#endif
ORBit_IMethod GNOME_Evolution_Wizard__imethods[GNOME_Evolution_Wizard_IMETHODS_LEN];
#ifdef __cplusplus
}
#endif /* __cplusplus */

#ifndef EXCLUDE_ORBIT_H
#include <orbit/orbit.h>

#endif /* EXCLUDE_ORBIT_H */
#endif
#undef ORBIT_IDL_SERIAL
